@@ -39,7 +39,7 @@ IBIS_SUBSTRAIT_OP_MAPPING = {
     "LPad": "lpad",
     "LStrip": "ltrim",
     "Max": "max",
-    "Mean": "mean",
+    "Mean": "avg",
     "Min": "min",
     "Modulus": "modulus",
     "Multiply": "multiply",
@@ -60,12 +60,15 @@ IBIS_SUBSTRAIT_OP_MAPPING = {
     "Sin": "sin",
     "Sqrt": "sqrt",
     "StartsWith": "starts_with",
+    "StringFind": "strpos",
     "StringConcat": "concat",
     "StringContains": "contains",
     "StringLength": "char_length",
     "StringReplace": "replace",
+    "StringSplit": "string_split",
     "StringSQLLike": "like",
     "Strip": "trim",
+    "StrRight": "right",
     "Substring": "substring",
     "Subtract": "subtract",
     "Sum": "sum",
